function [hdr] = read_nex_header(filename)

% READ_NEX_HEADER for Plexon *.nex file
%
% Use as
%   [hdr] = read_nex_header(filename)
%
% See also RAD_NEX_DATA, READ_NEX_EVENT

fid = fopen(filename, 'r', 'ieee-le');

% reading the file header
filheader.magicnumber     = fread(fid,4,'int8');
filheader.version         = fread(fid,1,'int32');
filheader.comment         = fread(fid,256,'int8');
filheader.frequency       = fread(fid,1,'double');
filheader.begvar          = fread(fid,1,'int32');
filheader.endvar          = fread(fid,1,'int32');
filheader.numvar          = fread(fid,1,'int32');
filheader.nextfileheader  = fread(fid,1,'int32');
filheader.padding         = fread(fid,256,'int8');

% reading the variable headers
for varlop=1:filheader.numvar
  varheader(varlop).typ        = fread(fid,1,'int32');
  version                      = fread(fid,1,'int32');
  varheader(varlop).nam        = fread(fid,64,'int8');
  varheader(varlop).offset     = fread(fid,1,'int32');
  varheader(varlop).cnt        = fread(fid,1,'int32');
  wirenumber                   = fread(fid,1,'int32');
  unitnumber                   = fread(fid,1,'int32');
  gain                         = fread(fid,1,'int32');
  filter                       = fread(fid,1,'int32');
  xpos                         = fread(fid,1,'double');
  ypos                         = fread(fid,1,'double');
  varheader(varlop).wfrequency = fread(fid,1,'double');
  varheader(varlop).adtomv     = fread(fid,1,'double');
  varheader(varlop).numsmp     = fread(fid,1,'int32');
  varheader(varlop).nummrk     = fread(fid,1,'int32');
  varheader(varlop).mrklen     = fread(fid,1,'int32');
  padding                      = fread(fid,68,'int8');
end

% put them together into one struct
header.fil       = filename;
header.filheader = filheader;
header.varheader = varheader;
status = fclose(fid);

% assign the obligatory items to the output FCDC header
numsmp = cell2mat({header.varheader.numsmp});
adindx = find(cell2mat({header.varheader.typ})==5);
hdr.nChans      = length(header.varheader);
hdr.Fs          = header.varheader(adindx(1)).wfrequency;   % take the sampling frequency from the first A/D channel
hdr.nSamples    = max(numsmp(adindx));                      % take the number of samples from the longest A/D channel
hdr.nTrials     = 1;                                        % it can always be interpreted as continuous data
hdr.nSamplesPre = 0;                                        % and therefore it is not trial based
for i=1:hdr.nChans
  hdr.label{i} = deblank(char(header.varheader(i).nam'));
end

% also remember the original header details
hdr.nex         = header;       
